import gzip
import os
import just
from auto_extract import parse_article
import tqdm
from urllib.parse import urlparse
import tldextract
from utils import KEYS_TO_KEEP

for x in tqdm.tqdm(just.glob("/home/pascal/nostalgia_data_chrome/meta/v1/*.json")):
    print("processing", x)
    meta = just.read(x)
    if "extruct" in meta:
        print("skipping", x)
        continue

    html_path = (
        "/home/pascal/nostalgia_data_chrome/html/" + x.split("/")[-1].rstrip(".json") + ".html.gz"
    )
    if os.path.exists(html_path):
        with gzip.GzipFile(html_path, "r") as f:
            html = f.read()
        article = parse_article(html, meta["url"])
        meta = article.to_dict(keys=KEYS_TO_KEEP, skip_if_empty=True)
        just.write(meta, x)
        os.system("touch '{}' -r '{}'".format(x, html_path))
        print("done", x)



from multiprocessing import Pool

import just
from auto_extract import parse_article

pool = Pool(4)

# extracts = pool.map(extruct.extract, file_contents)


data = just.multi_read("~/.nostalgia_chrome/html/*.json")
file_names, file_contents = data.keys(), data.values()


def extract_and_save(args):
    file_name, file_content = args
    url = file_content["url"]
    html = file_content["html"]
    parsed = parse_article(html, url)
    just.write(parsed, "~/.nostalgia_chrome/metadata/" + file_name.split("/")[-1])


zz = [extract_and_save(x) for x in zip(file_names, file_contents)]

z = pool.map(extract_and_save, zip(file_names, file_contents))


def recurser(obj, contain_str, container, parent=None):
    if isinstance(obj, dict):
        for k, v in obj.items():
            if contain_str in k:
                container.append(((k, v), parent))
                print(k, v)
            recurser(v, contain_str, container, obj)
    if isinstance(obj, list):
        for x in obj:
            recurser(x, contain_str, container, obj)
    if isinstance(obj, str):
        if contain_str in obj and len(obj) < 100:
            container.append((obj, parent))
            print(obj)



import os
import re
import just
import json
import gzip
from auto_extract import parse_article
import tqdm
from utils import KEYS_TO_KEEP


def slug_url(url):
    pre_slug = re.sub(r"[-\s]+", "-", url)
    slugged_url = re.sub(r"[^\w\s-]", "", pre_slug).strip().lower()[-150:]
    return slugged_url


for x in tqdm.tqdm(just.glob("/home/pascal/nostalgia_data_chrome/old/html/*.json")):
    ctime = os.path.getctime(x)
    with open(x) as f:
        print("processing", x)
        data = json.load(f)
        html = data["html"]
        url = data["url"]
        slugged_url = slug_url(url)
        article = parse_article(html, url)
        meta = article.to_dict(keys=KEYS_TO_KEEP, skip_if_empty=True)
        meta["creation_time"] = ctime
        meta["slugged_url"] = slugged_url
        html_path = "/home/pascal/nostalgia_data_chrome/html/{}_{}.html.gz".format(
            ctime, slugged_url
        )
        with gzip.GzipFile(html_path, "w") as f:
            f.write(html.encode("utf8"))
        meta_path = "/home/pascal/nostalgia_data_chrome/meta/v1/{}_{}.json".format(
            ctime, slugged_url
        )
        just.write(meta, meta_path)
        os.system("touch '{}' -r '{}'".format(html_path, x))
        os.system("touch '{}' -r '{}'".format(meta_path, x))
        just.remove(x)



import lxml.html
from bs4 import UnicodeDammit


def make_tree(html, domain=None):

    ud = UnicodeDammit(html, is_html=True)

    tree = lxml.html.fromstring(ud.unicode_markup)

    if domain is not None:
        tree.make_links_absolute(domain)

    for el in tree.iter():

        # remove comments
        if isinstance(el, lxml.html.HtmlComment):
            el.getparent().remove(el)
            continue

        if el.tag == 'script' and el.attrib.get("type") != "application/ld+json":
            el.getparent().remove(el)
            continue

    return tree



from datetime import datetime
import shutil
import os
import platform


def chrome_history_path(beta=False):
    if platform.system() == "Windows":
        beta = " Beta" if beta else ""
        if platform.release() == "XP":
            user_path = (
                "~/Local Settings/Application Data/Google/Chrome{}/User Data/Default/history"
            )
        else:
            user_path = "~/AppData/Local/Google{}/Chrome{}/User Data/Default/history"
    elif platform.system() == "Linux":
        beta = "-beta" if beta else ""
        user_path = "~/.config/google-chrome{}/Default/History".format(beta)
    elif platform.system() == "Darwin":
        beta = " Beta" if beta else ""
        user_path = "~/Library/Application Support/Google/Chrome{}/Default/history"
    else:
        raise OSError("Not sure of a path for your system")
    user_path = user_path.format(beta)
    # The Chrome default profile folder default locations are:

    # WinXP: [userdir]\Local Settings\Application Data\Google\Chrome\User Data\Default
    # Vista/7/8: [userdir]\AppData\Local\Google\Chrome\User Data\Default
    # Linux: [userdir]/.config/google-chrome/Default
    # OS X: [userdir]/Library/Application Support/Google/Chrome/Default
    # iOS: \Applications\com.google.chrome.ios\Library\Application Support\Google\Chrome\Default
    # Android: /userdata/data/com.android.chrome/app_chrome/Default

    return os.path.expanduser(user_path)


def backup_history(base="~/nostalgia_data_chrome", beta=False):
    """ Copies the Chrome History sqlite to a safe location """
    chp = chrome_history_path(beta)
    target = os.path.expanduser(
        os.path.join(base, "sqlite/{}_history".format(datetime.now().date()))
    )
    shutil._ensure_directory(target)
    shutil.copy2(chp, target)
    latest = os.path.expanduser(os.path.join(base, "sqlite/latest"))
    os.symlink(target, latest)



from nostalgia_chrome.server.app import run_server
from nostalgia_chrome.store_backup import backup_history
from nostalgia_chrome import print_version


def _main():
    import fire as _fire

    _fire.Fire()


if __name__ == "__main__":
    _main()



import just
import time
from datetime import datetime
import gzip
import os
import re
from collections import deque

import lxml.html

from flask import Flask, jsonify, request, make_response, current_app


from nostalgia_chrome.server.cors import crossdomain
from nostalgia_chrome.server.utils import make_tree

BASE_PATH = "~/nostalgia_data/"
META_PATH = BASE_PATH + "meta.jsonl"

VIDEO_PATH = BASE_PATH + "videos_watched.jsonl"
app = Flask(__name__, static_folder=BASE_PATH + "html")

#  html = just.read("index.html")

last = []
last_urls = deque(maxlen=5)


@app.route("/", methods=["GET", "POST", "OPTIONS"])
def root():
    if not last:
        return ""
    return last[-1]


# @app.route("/diff", methods=["GET", "POST", "OPTIONS"])
# def view_diff():
#     return view_diff_html(last[-2], last[-1])


blocklist = ["/localhost", "file:/", "/127.0.0.1", "chrome:", "localhost:", "/tmp/"]


def slug_url(url):
    pre_slug = re.sub(r"[-\s]+", "-", url)
    slugged_url = re.sub(r"[^\w\s-]", "", pre_slug).strip().lower()[-150:]
    return slugged_url


@app.route("/post_json", methods=["GET", "POST", "OPTIONS"])
@crossdomain(origin="*", headers="Content-Type")
def add_text():
    url = request.json["url"]
    print("url", url)

    if any([y in url for y in blocklist]):
        print("blocked", [y for y in blocklist if y in url])
        return jsonify({})
    html = request.json["html"]
    html = lxml.html.tostring(lxml.html.fromstring(html.encode("utf8")))

    tree = make_tree(html, url)

    html = lxml.html.tostring(tree).decode("utf8")

    slugged_url = slug_url(url)

    t1 = time.time()
    # meta_path = BASE_PATH / "meta/v1/{}_{}.json".format(t1, slugged_url)
    # try:
    #     article = parse_article(html, url)
    #     metadata = article.to_dict(keys=ARTICLE_KEYS_TO_KEEP, skip_if_empty=True)
    # except Exception as e:
    #     metadata = {"error": str(e)}
    # metadata["creation_time"] = t1
    # metadata["slugged_url"] = slugged_url
    # with open(meta_path, "w") as f:
    #     json.dump(metadata, f, indent=4)
    # just.write(metadata, meta_path)

    html_path = BASE_PATH + "html/{}_{}.html.gz".format(t1, slugged_url)
    print("html_path", html_path)
    just.write(html, html_path)

    obj = {"path": str(html_path), "url": url, "time": str(time.time())}
    print("META_PATH", META_PATH)
    just.append(obj, META_PATH)

    last.append(html)
    last_urls.append(url)
    print("saved", url)
    return jsonify({"urls": list(last_urls)})


@app.route("/video_watched", methods=["GET", "POST", "OPTIONS"])
@crossdomain(origin="*", headers="Content-Type")
def add_video_watch():
    just.append(request.json, VIDEO_PATH)
    print("video watched")
    return ""


@app.route("/view_cache", methods=["GET", "POST", "OPTIONS"])
@crossdomain(origin="*", headers="Content-Type")
def view_cache():
    filename = request.args.get("filename")
    resp = make_response(current_app.send_static_file(filename))
    resp.headers["Content-Type"] = "text/html"
    resp.headers["Content-Encoding"] = "gzip"
    return resp


@app.route("/list", methods=["GET", "POST", "OPTIONS"])
@crossdomain(origin="*", headers="Content-Type")
def ls():
    keyword = request.args.get("keyword")
    files = os.listdir(BASE_PATH / "html")
    if keyword is not None:
        files = [x for x in files if keyword in x]
    files = files[:500]
    body = "\n".join([f"<a href='/view_cache?filename={x}'>{x}</a></br>" for x in files])
    return "<html><body>{}</body></html>".format(body)


def run_server(host="127.0.0.1", port=21487):
    """ Run nostalgia_chrome which receives pages when visiting a page in Chrome. """
    app.run(host, port)


if __name__ == "__main__":
    run_server()



from setuptools import setup
from setuptools import find_packages

with open("README.md") as f:
    LONG_DESCRIPTION = f.read()
MAJOR_VERSION = "0"
MINOR_VERSION = "0"
MICRO_VERSION = "24"
VERSION = "{}.{}.{}".format(MAJOR_VERSION, MINOR_VERSION, MICRO_VERSION)

install_requires = ["lxml", "flask", "fire", "bs4", "just"]

setup(
    name="nostalgia_chrome",
    version=VERSION,
    description="Self tracking your online life!",
    long_description=LONG_DESCRIPTION,
    long_description_content_type="text/markdown",
    url="https://github.com/nostalgia-dev/nostalgia_chrome",
    author="Pascal van Kooten",
    install_requires=install_requires,
    author_email="kootenpv@gmail.com",
    license="MIT",
    entry_points={"console_scripts": ["nostalgia_chrome = nostalgia_chrome.__main__:_main"]},
    classifiers=[
        "Environment :: Console",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: MIT License",
        "Operating System :: Microsoft",
        "Operating System :: MacOS :: MacOS X",
        "Operating System :: Unix",
        "Operating System :: POSIX",
        "Programming Language :: Python",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.4",
        "Programming Language :: Python :: 3.5",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Topic :: Software Development",
        "Topic :: Software Development :: Libraries :: Python Modules",
        "Topic :: Utilities",
    ],
    packages=find_packages(),
    requires_python=">=3.4.0",
    zip_safe=False,
    platforms="any",
)



import sys
from nostalgia_chrome.server.app import run_server

__project__ = "nostalgia_chrome"
__version__ = "0.0.24"
__repo__ = "https://github.com/nostalgia-dev/nostalgia_chrome"


def print_version():
    """ Prints the current version of nostalgia_chrome, and more """
    sv = sys.version_info
    py_version = "{}.{}.{}".format(sv.major, sv.minor, sv.micro)
    version_parts = __version__.split(".")
    s = "{} version: [{}], Python {}".format(__project__, __version__, py_version)
    s += "\nMajor version: {}  (breaking changes)".format(version_parts[0])
    s += "\nMinor version: {}  (extra feature)".format(version_parts[1])
    s += "\nMicro version: {} (commit count)".format(version_parts[2])
    s += "\nFind out the most recent version at {}".format(__repo__)
    return s



from datetime import datetime
from dateutil.relativedelta import relativedelta
from metadate import parse_date as _parse_date


class Time:
    def __init__(self, start, end=None, **rd_args):
        self._start = start
        self._end = end or start
        self.rd_args = rd_args

    @property
    def rd(self):
        return relativedelta(**self.rd_args)

    @property
    def start(self):
        return self._start - self.rd

    @property
    def end(self):
        return self._end + self.rd

    @classmethod
    def from_md(cls, text, **rd_args):
        md = _parse_date(text)
        if md is None:
            return None
        return cls(md.start_date, md.end_date, **rd_args)

    @classmethod
    def from_epoch(cls, integer, **rd_args):
        tmp = datetime.fromtimestamp(integer)
        return cls(tmp, **rd_args)

    @classmethod
    def from_dt(cls, dt, **rd_args):
        return cls(dt, **rd_args)
